@@ -1,4 +1,5 @@
 //! contains all of feroxbuster's filters
+use serde::{Deserialize, Serialize};
 use std::any::Any;
 use std::fmt::Debug;
 
@@ -6,12 +7,14 @@ use crate::response::FeroxResponse;
 use crate::traits::{FeroxFilter, FeroxSerialize};
 
 pub use self::container::FeroxFilters;
+pub(crate) use self::empty::EmptyFilter;
 pub use self::init::initialize;
 pub use self::lines::LinesFilter;
 pub use self::regex::RegexFilter;
 pub use self::similarity::SimilarityFilter;
 pub use self::size::SizeFilter;
 pub use self::status_code::StatusCodeFilter;
+pub(crate) use self::utils::{create_similarity_filter, filter_lookup};
 pub use self::wildcard::WildcardFilter;
 pub use self::words::WordsFilter;
 
@@ -26,3 +29,5 @@ mod container;
 #[cfg(test)]
 mod tests;
 mod init;
+mod utils;
+mod empty;
