@@ -8,6 +8,8 @@ use indicatif::ProgressBar;
 use lazy_static::lazy_static;
 use tokio::sync::Semaphore;
 
+use crate::filters::{create_similarity_filter, EmptyFilter, SimilarityFilter};
+use crate::Command::AddFilter;
 use crate::{
     event_handlers::{
         Command::{AddError, AddToF64Field, AddToUsizeField, SubtractFromUsizeField},
@@ -47,7 +49,7 @@ async fn check_for_user_input(
 
     // todo write a test or two for this function at some point...
     if pause_flag.load(Ordering::Acquire) {
-        match scanned_urls.pause(true).await {
+        match scanned_urls.pause(true, handles.clone()).await {
             Some(MenuCmdResult::Url(url)) => {
                 // user wants to add a new url to be scanned, need to send
                 // it over to the event handler for processing
@@ -63,6 +65,38 @@ async fn check_for_user_input(
                         .unwrap_or_else(|e| log::warn!("Could not update overall scan bar: {}", e));
                 }
             }
+            Some(MenuCmdResult::Filter(mut filter)) => {
+                let url = if let Some(SimilarityFilter { original_url, .. }) =
+                    filter.as_any().downcast_ref::<SimilarityFilter>()
+                {
+                    original_url.to_owned()
+                } else {
+                    String::new()
+                };
+
+                if !url.is_empty() {
+                    // filter was a SimilarityFilter and now we have a url to request.
+                    //
+                    // The reason for this janky structure is that `filter.as_any().downcast_ref`
+                    // isn't Send so we can't call create_similarity_filter(...).await, within
+                    // the if let Some ipso-facto, janky code /shrug
+                    let real_filter = create_similarity_filter(&url, handles.clone())
+                        .await
+                        .unwrap_or_default();
+
+                    if real_filter.original_url.is_empty() {
+                        // failed to create filter
+                        filter = Box::new(EmptyFilter {});
+                    } else {
+                        filter = Box::new(real_filter)
+                    }
+                }
+
+                handles
+                    .filters
+                    .send(AddFilter(filter))
+                    .unwrap_or_else(|e| log::warn!("Could not add new filter: {}", e));
+            }
             _ => {}
         }
     }
